/**
  *  \file client/dialogs/basetaskbuild.cc
  *  \brief WBaseTaskShipBuildDialog dialog
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/basetaskbuild.h"
#include "client/widgets/helpwidget.h"
#include "ui/layout.h"
#include "ui/widgets/button.h"
#include "util/nls.h"
#include "ui/widgets/quit.h"

/** Constructor.
    \param planet Planet to work on (can be fake)
    \param hulls Hulls to offer */
WBaseTaskShipBuildDialog::WBaseTaskShipBuildDialog(GPlanet& planet, std::vector<int>& hulls)
    : WShipBuildDialog(_("Build Ship"), planet, false, hulls)
{
    init();
}

WBaseTaskShipBuildDialog::~WBaseTaskShipBuildDialog()
{ }

void
WBaseTaskShipBuildDialog::init()
{
    UIGroup& g = h.add(new UIGroup(UIHBoxLayout::instance5));

    UIButton& ok     = h.add(new UIButton(2000, _("Enter - Build"), SDLK_RETURN));
    UIButton& cancel = h.add(new UIButton(2001, _("Cancel"), SDLK_ESCAPE));
    UIButton& bill   = h.add(new UIButton(2004, _("D - Detailed Bill"), 'd'));
    g.add(ok);
    g.add(cancel);
    g.add(bill);
    g.add(h.add(new UISpacer()));
    g.add(h.add(new UIButton(_("Help"), 'h')));

    add(g);
    add(h.add(new WHelpWidget("pcc2:basetaskscreen")));
    add(h.add(new UIQuit(2001)));

    ok.addStop();
    cancel.addStop();
    bill.sig_fired.add(static_cast<WShipBuildDialog*>(this), &WShipBuildDialog::onDetailedBill);

    action.setUsePartsFromStorage(true);
    action.setUseTechUpgrade(true);
    onPlanetChanged();

    pack();
}

/** Run this dialog.
    \retval true User confirmed
    \retval false User canceled */
bool
WBaseTaskShipBuildDialog::runDialog()
{
    return ui_root->runModal(*this) == 2000;
}

/** Get selected build order. */
const TBuildOrder&
WBaseTaskShipBuildDialog::getBuildOrder()
{
    return action.getBuildOrder();
}
