/**
  *  \file client/dialogs/consolelog.cc
  *  \brief Console Log Window
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/consolelog.h"
#include "util/console.h"
#include "ui/layout.h"
#include "gfx/palette.h"
#include "ui/widgets/keytranslator.h"
#include "ui/uiglobal.h"
#include "util/nls.h"
#include "ui/widgets/button.h"
#include "ui/widgets/quit.h"

/** Constructor. Builds a console log window.
    \param name Name of the window
    \param nlines Number of console lines to display */
WConsoleLogWindow::WConsoleLogWindow(string_t name, int nlines)
    : UIWindow(name, BLUE_WINDOW, COLOR_GRAY),
      console_view(::console, nlines)
{
    init();
}

/** Create the window. */
void
WConsoleLogWindow::init()
{
    // VBox
    //   WConsoleView
    //   HBox
    //     UISpacer
    //     UIButton "Close"

    console_view.setSynchronousMode(true);

    UIKeyTranslator& keytrans = h.add(new UIKeyTranslator());
    keytrans.addStop(' ', 0);
    keytrans.addStop(SDLK_ESCAPE, 0);

    UIButton& button = h.add(new UIButton(1000, _("Close"), SDLK_RETURN));
    button.setState(st_Disabled, true);
    button.addStop();

    UIGroup& hbox = h.add(new UIGroup(UIHBoxLayout::instance5));
    hbox.add(h.add(new UISpacer()));
    hbox.add(button);

    setLayout(UIVBoxLayout::instance5);
    add(console_view);
    add(hbox);
    add(keytrans);
    add(h.add(new UIQuit(0)));
    pack();

    ui_root->centerWidget(*this);
}

/** Scroll after end, such that console appears empty.
    \see WConsoleView::scrollAfterEnd */
void
WConsoleLogWindow::scrollAfterEnd()
{
    console_view.scrollAfterEnd();
}

/** Open this window. The also causes immediate display of the window. */
void
WConsoleLogWindow::open()
{
    ui_root->add(*this);
    ui_root->performDeferredRedraws();
}

/** Wait for user confirmation. Waits until the user closes the
    console using the "close" button or by pressing Enter/Space. */
void
WConsoleLogWindow::waitForConfirmation()
{
    setStateOf(1000, st_Disabled, false);
    ui_root->run();
    setStateOf(1000, st_Disabled, true);
}

