/**
  *  \file client/markerconfig.h
  *  \brief Marker Configuration
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_MARKERCONFIG_H
#define PCC_V2_CLIENT_MARKERCONFIG_H

#include "cpluslib/string.h"
#include "cpluslib/types.h"
#include "util/conf.h"

/** Config file option for a canned marker. Each canned marker has the following
    properties:
    - a type (see GDrawing::setMarkerKind)
    - a color (user color index, see GDrawing::getColorFromUserColor)
    - a note (empty by default, causing a predefined string to be displayed) */
class ConfigMarkerOption : public ConfigOption {
 public:
    ConfigMarkerOption(Config& container, const char* name, const char* deflt);
    void set(string_t value);
    string_t toString() const;

    uint8_t  getColorIndex() const;
    void     setColorIndex(uint8_t color);
    uint8_t  getType() const;
    void     setType(uint8_t type);
    string_t getNote() const;
    void     setNote(string_t note);

    enum { NUM_CANNED_MARKERS = 10 };

    static ConfigMarkerOption& getCannedMarker(int i);

 private:
    uint8_t  type;
    uint8_t  color;
    string_t note;
};

#endif
