/**
  *  \file ui/commands.h
  *  \brief Command Numbers
  *
  *  This module defines the common cm_XXX constants.
  *
  *  (c) 2001-2018 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_COMMANDS_H
#define PCC_V2_UI_COMMANDS_H

#include "ui/event.h"

/** Standard Command Codes. Assigning command codes while not
    causing conflicts is a major headache. So I decided on the
    following scheme:
    - all positive values are available to every window
    - [-1000,0) contains common commands and those used by the kernel
    - (-inf,-1000) is assigned to windows that wish their own range

    Note that these are not actually command codes; they are primarily
    widget ids. Because they are called cm_XXX in PCC 1.x, I also call
    them so here.

    Some command codes remain, for events posted internally (cm_INT). */

class UIWidget;

enum {
    /* Standard Codes */
    cm_Enter     = -1000,       ///< "Enter", "Confirm"
    cm_Escape,                  ///< "ESC", "Cancel"
    cm_Yes,                     ///< "Yes"
    cm_No,                      ///< "No"

    /* Internal commands */
    cm_INT_QueryReferencePoint,
    cm_INT_Push,
    cm_INT_Unpush,

    /* Commands available for current window */
    cm_ControlScreenFirst   = -2000 // 1000
};

struct TReferencePointArg {
    int x, y;

    TReferencePointArg()
        : x(0), y(0) { }
};

#endif
